@@ -1,4 +1,3 @@
-from tkinter import N
 import sympy as sy
 import IPython
 
@@ -11,7 +10,7 @@ def Inicializar(n):
     Estilo = "textbf"#bold
   elif n ==3:
     Estilo = "texttt"#typewriter
-  elif n == 5:
+  elif n == 4:
     Estilo = "textit"#italic
 
   DatosList = []
@@ -39,14 +38,39 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
     c_componente = elemento
   
   if Tipo == "Ecuacion":#Si hemos identificado el elemento ingresado como una ecuación, entonces la imprimimos en rojo
-    texto = sy.latex(elemento.args[0]) + "=" + sy.latex(elemento.args[1])
-    IPython.display.display("\\"+Estilo+"{"+IPython.display.Latex(r"\textcolor{"+str(color)+"}{"+texto+"}")+"}")
+
+    a = sy.latex(elemento.args[0])
+
+    b = "="
+
+    c = sy.latex(elemento.args[1])
+
+    texto = a+b+c
+    texto = texto.replace("text", Estilo)
+
+    IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
 
   if Tipo == "Componente":#Si hemos identificado el elemento ingresado como un componente, entonces lo imprimimos en rojo
     if not isinstance(c_componente[0],str):#isinstance(c_componente[0],sy.core.symbol.Symbol) or isinstance(c_componente[0],sy.core.symbol.Symbol) :
-      IPython.display.display("\\"+Estilo+"{"+IPython.display.Latex(r"\textcolor{"+str(color)+"}{"+sy.latex(c_componente[0])+" = "+sy.latex(Redondear(c_componente[1]))+"}")+)
+      a = sy.latex(c_componente[0])
+
+      b = " = "
+
+      c = sy.latex(Redondear(c_componente[1]))
+
+      texto = a + b + c
+      texto = texto.replace("text", Estilo)
+      IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
     elif isinstance(c_componente[0],str):
-      IPython.display.display("\\"+Estilo+"{"+IPython.display.Latex(r"\textcolor{"+str(color)+"}{"+c_componente[0]+" = "+sy.latex(Redondear(c_componente[1]))+"}")+"}")
+      a = sy.latex(c_componente[0])
+      
+      b = " = "
+
+      c = sy.latex(Redondear(c_componente[1]))
+
+      texto = a + b + c
+      texto = texto.replace("text", Estilo)
+      IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
   #Código para actualizar valores: if isinstance(element[1], sy.Expr):element = [element[0],element[1].subs(c_componente[0],c_componente[1])]
 
 
@@ -65,17 +89,27 @@ def E(expr,color = "red"):
       #Es decir, si es un simbolo sin valor (None) o coleccion de simbolos. Entonces:
       DataRealSymbolList.append([element[0],element[0]])
   #display(DataRealSymbolList)
-  
+
 
   if isinstance(expr,sy.core.relational.Equality):
-    D(expr.subs(DataRealSymbolList))
-    #D(sy.N(expr.subs(DatosList)))
+    texto = sy.latex(expr)
+    for element in DataRealSymbolList:
+      texto = texto.replace(sy.latex(element[0]), sy.latex(element[1]))
+
+    #D(expr.subs(DataRealSymbolList))
+    IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
   
   if isinstance(expr,list):
-    D([expr[0],expr[1].subs(DataRealSymbolList)])
+    texto = sy.latex(expr[1])
+    for element in DataRealSymbolList:
+      texto = texto.replace(sy.latex(element[0]), sy.latex(element[1]))
+
+    texto = sy.latex(expr[0]) +" = "+texto
+    #D([expr[0],expr[1].subs(DataRealSymbolList)])
+    IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
     #D([expr[0],sy.N(expr[1].subs(DatosList))])
 
-def G(c_componente):#Guardar
+def S(c_componente):#Guardar
   global DatosList
   dentro = False
   for element in DatosList:
